summaryrefslogtreecommitdiff
path: root/src/database/database.hpp
diff options
context:
space:
mode:
authorCedric Nugteren <web@cedricnugteren.nl>2017-09-23 20:40:38 +0200
committerCedric Nugteren <web@cedricnugteren.nl>2017-09-23 20:40:38 +0200
commit255f09843cb4a0a10e04a9581184750da0d36593 (patch)
treebcedb6766ea194bf6c1bc7cfeb7a9394af1f02b5 /src/database/database.hpp
parent0d8313708ca84f5338f405ae9b3261188e87b6f7 (diff)
Made program and binary databases dependent on the routine parameters on top of the name
Diffstat (limited to 'src/database/database.hpp')
-rw-r--r--src/database/database.hpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/database/database.hpp b/src/database/database.hpp
index 4cb0bf6a..04e9f095 100644
--- a/src/database/database.hpp
+++ b/src/database/database.hpp
@@ -53,7 +53,8 @@ class Database {
// Obtain a list of OpenCL pre-processor defines based on the parameters
std::string GetDefines() const;
- // Retrieves the names of all the parameters
+ // Retrieves the values or names of all the parameters
+ std::string GetValuesString() const;
std::vector<std::string> GetParameterNames() const;
private: